fix uci_parse_tuple
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index 8a89b71..cfcdf3e 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -263,10 +263,11 @@ extern int uci_revert(struct uci_context *ctx, struct uci_package **p, char *sec
 /**
  * uci_parse_argument: parse a shell-style argument, with an arbitrary quoting style
  * @ctx: uci context
- * @str: pointer to the input string (will be changed to the end of the parsed string)
+ * @stream: input stream
+ * @str: pointer to the current line (use NULL for parsing the next line)
  * @result: pointer for the result
  */
-extern int uci_parse_argument(struct uci_context *ctx, char **str, char **result);
+extern int uci_parse_argument(struct uci_context *ctx, FILE *stream, char **str, char **result);
 
 /* UCI data structures */
 enum uci_type {
@@ -278,9 +279,10 @@ enum uci_type {
 };
 
 enum uci_flags {
-       UCI_FLAG_STRICT =      (1 << 0), /* strict mode for the parser */
-       UCI_FLAG_PERROR =      (1 << 1), /* print parser error messages */
-       UCI_FLAG_EXPORT_NAME = (1 << 2), /* when exporting, name unnamed sections */
+       UCI_FLAG_STRICT =        (1 << 0), /* strict mode for the parser */
+       UCI_FLAG_PERROR =        (1 << 1), /* print parser error messages */
+       UCI_FLAG_EXPORT_NAME =   (1 << 2), /* when exporting, name unnamed sections */
+       UCI_FLAG_SAVED_HISTORY = (1 << 3), /* store the saved history in memory as well */
 };
 
 struct uci_element
@@ -316,23 +318,6 @@ struct uci_context
        int bufsz;
 };
 
-struct uci_parse_context
-{
-       /* error context */
-       const char *reason;
-       int line;
-       int byte;
-
-       /* private: */
-       struct uci_package *package;
-       struct uci_section *section;
-       bool merge;
-       FILE *file;
-       const char *name;
-       char *buf;
-       int bufsz;
-};
-
 struct uci_package
 {
        struct uci_element e;
@@ -344,6 +329,7 @@ struct uci_package
        /* private: */
        int n_section;
        struct uci_list history;
+       struct uci_list saved_history;
 };
 
 struct uci_section